View source: R/receptiviti_frameworks.R
| receptiviti_frameworks | R Documentation |
Retrieve the list of frameworks available to your account.
receptiviti_frameworks(url = Sys.getenv("RECEPTIVITI_URL"),
key = Sys.getenv("RECEPTIVITI_KEY"),
secret = Sys.getenv("RECEPTIVITI_SECRET"))
url, key, secret |
Request arguments; same as those in |
A character vector containing the names of frameworks available to your account.
## Not run:
# see which frameworks are available to your account
frameworks <- receptiviti_frameworks()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.