powered by
Retrieve the list of frameworks available to your account.
receptiviti_frameworks(url = Sys.getenv("RECEPTIVITI_URL"), key = Sys.getenv("RECEPTIVITI_KEY"), secret = Sys.getenv("RECEPTIVITI_SECRET"))
A character vector containing the names of frameworks available to your account.
Request arguments; same as those in receptiviti.
receptiviti
if (FALSE) { # see which frameworks are available to your account frameworks <- receptiviti_frameworks() }
Run the code above in your browser using DataLab